@@ -13,7 +13,7 @@ mod map_to_result;
 pub use after::After;
 pub use and_then::AndThen;
 pub use before::Before;
-pub use endpoint::{fn_endpoint, Endpoint, EndpointExt};
+pub use endpoint::{make, make_sync, BoxEndpoint, Endpoint, EndpointExt, IntoEndpoint};
 pub use map_err::MapErr;
 pub use map_ok::MapOk;
 pub use map_to_response::MapToResponse;
